summaryrefslogtreecommitdiff
path: root/src/include/data_localgame.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/data_localgame.h')
-rw-r--r--src/include/data_localgame.h4
1 files changed, 3 insertions, 1 deletions
diff --git a/src/include/data_localgame.h b/src/include/data_localgame.h
index 5f67783..b740b27 100644
--- a/src/include/data_localgame.h
+++ b/src/include/data_localgame.h
@@ -11,7 +11,9 @@ typedef struct {
typedef struct {
SDL_Surface *screen, *terrain, *stencil;
- SDL_Rect viewport; // Viewport top-left corner coords in screen
+ SDL_Rect viewport; // Viewport top-left corner coords in screen
+ int dirtRectsCount; // Dirt rectangle to refresh for current tick
+ SDL_Rect *dirtRects;
} gameGraphics_t;